from kinetick.strategies import strategy


# ===========================================
if __name__ == "__main__":

    algo = strategy()
    algo.run()
